@@ -1,5 +1,5 @@
 from plurally.models.action.email_smtp import SendEmailSMTP  # noqa: F401
-from plurally.models.source.email_imap import EmailSourceIMAP  # noqa: F401
+from plurally.models.source.email_imap import EmailSourceIMAP, NewEmail  # noqa: F401
 
 __all__ = [
     "EmailSourceIMAP",
