@@ -1,9 +1,9 @@
 from plurally.models.source.constant import Integer, Number, Text  # noqa: F401
-from plurally.models.source.email_imap import EmailSourceIMAP  # noqa: F401
+from plurally.models.source.email_imap import NewEmail  # noqa: F401
 
 __all__ = [
     "Number",
     "Integer",
     "Text",
-    "EmailSourceIMAP",
+    "NewEmail",
 ]
